@@ -53,6 +53,25 @@ print(mdri)
 #                   parallel = TRUE,
 #                   cores=4)
 
+## ---- results='hide'-----------------------------------------------------
+mdri <- mdrical(data=excalibdata,
+                subid_var = "SubjectID",
+                time_var = "DaysSinceEDDI",
+                recency_cutoff_time = 730.5,
+                inclusion_time_threshold = 800,
+                functional_forms = c("cloglog_linear","logit_cubic"),
+                recency_rule = "independent_thresholds",
+                recency_vars = c("Result","VL"),
+                recency_params = c(10,0,1000,1),
+                n_bootstraps = 10,
+                alpha = 0.05,
+                plot = TRUE,
+                output_bs_parms = TRUE)
+
+## ---- fig.width=6.5, fig.height=5, fig.align="center", fig.show='hold'----
+print(mdri$Models)
+print(mdri$BSparms)
+
 ## ------------------------------------------------------------------------
 frrcal(data=excalibdata,
              subid_var = "SubjectID",
